/**
 * EasyBeans
 * Copyright (C) 2009-2011 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EJBContainer.java 6008 2011-10-17 13:41:22Z benoitf $
 * --------------------------------------------------------------------------
 */

package javax.ejb.embeddable;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.ServiceLoader;
import java.util.Set;

import javax.ejb.EJBException;
import javax.ejb.spi.EJBContainerProvider;

/**
 * Used to execute an EJB application in an embeddable container.
 * @see <a href="http://www.jcp.org/en/jsr/detail?id=318">EJB 3.1 specification</a>
 * @author Florent Benoit
 * @since EJB 3.1 version.
 */

public abstract class EJBContainer {

    static {}
    
    /**
     * Standard property name for specifying the application name of the EJB modules executing within the embeddable container.
     */
    public static final String APP_NAME = "javax.ejb.embeddable.appName";

    /**
     * Standard property name for specifying the embeddable container implementation bootstrap class.
     */
    public final static String PROVIDER = "javax.ejb.embeddable.provider";

    /**
     * Standard property name for specifying the set of modules to be initialized.
     */
    public static final String MODULES = "javax.ejb.embeddable.modules";

    /**
     * Shutdown an embeddable EJBContainer instance.
     */
    public abstract void close();

    /**
     * Create and initialize an embeddable EJB container.
     */
    public static EJBContainer createEJBContainer() {
        return createEJBContainer(null);
    }

    /**
     * Create and initialize an embeddable EJB container with a set of configuration properties.
     * @param properties
     * @return
     */
    public static EJBContainer createEJBContainer(java.util.Map<?, ?> properties) {
        EJBContainer container = null;
        

        for (Map.Entry me: properties.entrySet()) {
        }
        return container;
    }
    
    
    /**
     * Retrieve a naming context for looking up references to session beans executing in the embeddable container.
     * @return
     */
    public abstract javax.naming.Context getContext();

}
